@@ -9,26 +9,12 @@
  *
  * header/footer structures courtesy of the GIMP Targa plugin 
  */
-
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
-#include "common.h"
-#include <stdio.h>
-#include <string.h>
+#include "loader_common.h"
 #include <sys/stat.h>
 #include <sys/mman.h>
-#include "image.h"
 #include "colormod.h"
 #include "blend.h"
 
-char                load(ImlibImage * im, ImlibProgressFunction progress,
-                         char progress_granularity, char immediate_load);
-char                save(ImlibImage * im, ImlibProgressFunction progress,
-                         char progress_granularity);
-void                formats(ImlibLoader * l);
-
 /* flip an inverted image - see RLE reading below */
 static void         tgaflip(DATA32 * in, int w, int h);
 
@@ -297,9 +283,8 @@ load(ImlibImage * im, ImlibProgressFunction progress,
    im->w = (header->widthHi << 8) | header->widthLo;
    im->h = (header->heightHi << 8) | header->heightLo;
 
-   if ((im->w > 32767) || (im->w < 1) || (im->h > 32767) || (im->h < 1))
+   if ((im->w < 1) || (im->h < 1) || (im->w > 8192) || (im->h > 8192))
      {
-        im->w = 0;
 	munmap(seg, ss.st_size);
         close(fd);
         return 0;
@@ -318,7 +303,7 @@ load(ImlibImage * im, ImlibProgressFunction progress,
    if (((!im->data) && (im->loader)) || (immediate_load) || (progress))
      {
         unsigned long       datasize;
-        unsigned char      *bufptr;
+        unsigned char      *bufptr, *bufend;
         DATA32             *dataptr;
 
         int                 y;
@@ -346,6 +331,7 @@ load(ImlibImage * im, ImlibProgressFunction progress,
 
         /* bufptr is the next byte to be read from the buffer */
         bufptr = filedata;
+	bufend = filedata + datasize;
 
         /* dataptr is the next 32-bit pixel to be filled in */
         dataptr = im->data;
@@ -418,9 +404,10 @@ load(ImlibImage * im, ImlibProgressFunction progress,
              unsigned char       curbyte, red, green, blue, alpha;
              DATA32             *final_pixel = dataptr + im->w * im->h;
 
-             /* loop until we've got all the pixels */
-             while (dataptr < final_pixel)
-               {
+             /* loop until we've got all the pixels or run out of input */
+	     while ((dataptr < final_pixel) &&
+		    ((bufptr + 1 + (bpp / 8)) < bufend))
+	       {
                   int                 count;
 
                   curbyte = *bufptr++;
@@ -437,7 +424,7 @@ load(ImlibImage * im, ImlibProgressFunction progress,
                               green = *bufptr++;
                               red = *bufptr++;
                               alpha = *bufptr++;
-                              for (i = 0; i < count; i++)
+			    for (i = 0; (i < count) && (dataptr < final_pixel); i++)
                                 {
                                    WRITE_RGBA(dataptr, red, green, blue, alpha);
                                    dataptr++;
@@ -448,7 +435,7 @@ load(ImlibImage * im, ImlibProgressFunction progress,
                               blue = *bufptr++;
                               green = *bufptr++;
                               red = *bufptr++;
-                              for (i = 0; i < count; i++)
+			    for (i = 0; (i < count) && (dataptr < final_pixel); i++)
                                 {
                                    WRITE_RGBA(dataptr, red, green, blue,
                                               (char)0xff);
@@ -458,7 +445,7 @@ load(ImlibImage * im, ImlibProgressFunction progress,
 
                            case 8:
                               alpha = *bufptr++;
-                              for (i = 0; i < count; i++)
+			    for (i = 0; (i < count) && (dataptr < final_pixel); i++)
                                 {
                                    WRITE_RGBA(dataptr, alpha, alpha, alpha,
                                               (char)0xff);
@@ -473,7 +460,7 @@ load(ImlibImage * im, ImlibProgressFunction progress,
                     {
                        int                 i;
 
-                       for (i = 0; i < count; i++)
+                       for (i = 0; (i < count) && (dataptr < final_pixel); i++)
                          {
                             switch (bpp)
                               {
